@@ -1,5 +1,5 @@
 #!/bin/sh -f
-# $Id: pv.sh,v 1.3 2002/02/21 21:49:28 giles Exp $
+# $Id: pv.sh 8104 2007-07-05 10:41:52Z till $
 #
 # pv - preview a specified page of a dvi file in a Ghostscript window
 # usage: pv page file
@@ -25,14 +25,18 @@ fi
 # are held on the system."  So we have deleted this line, and also removed
 # the -D switch from the call of dvips below.
 #
-TEMPDIR=.
+
+# This definition is changed on install to match the
+# executable name set in the makefile
+GS_EXECUTABLE=gs
+
 PAGE=$1
 shift
-FILE=$1
-TEMPFILE=`mktemp -t ${FILE}XXXXXXXXXX` || exit 1
+FILE="$1"
 shift
-trap "rm -rf $TEMPFILE" 0 1 2 15
-#dvips -D$RESOLUTION -p $PAGE -n 1 $FILE $* -o $FILE.$$.pv
-dvips -p $PAGE -n 1 $FILE $* -o $TEMPFILE
-gs $TEMPFILE
+tmpfile=`mktemp -t ${FILE}XXXXXXXXXX` || exit 1
+trap "rm -rf $tmpfile" 0 1 2 15
+#dvips -D$RESOLUTION -p $PAGE -n 1 "$FILE" "$@" -o $tmpfile
+dvips -p $PAGE -n 1 "$FILE" "$@" -o $tmpfile
+$GS_EXECUTABLE $tmpfile
 exit 0
